'use strict';

var ExtratoObraController = angular.module('ExtratoObraController', []);

ExtratoObraController.controller('ExtratoObraCtrl', ['$scope', '$location', '$filter', 'Fornecedor', '$routeParams', 'Relatorio', 'Construcao', 'Fonte', 'CacheApp', 'Compra',
  ($scope, $location, $filter, Fornecedor, $routeParams, Relatorio, Construcao, Fonte, CacheApp, Compra) => {

    $scope.getFornecedores = () => {
        var params = {IdClienteDono: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : $scope.sessao.IdCliente};
        Fornecedor.getFornecedores(params,
            (data) => {
                $scope.fornecedores = data.Instance;
                $scope.fornecedores.forEach(f => {
                    f.Id = f.IdFornecedor
                })
                $scope.loadPage();
            });
        }

    $scope.getRelatorioExtratoObra = () => {
        var IdsConstrucao = []
        var IdsFonte = []
        var IdsFornecedores = []

        if ($scope.relatorio.Construcoes)
            $scope.relatorio.Construcoes.forEach(c => {
                IdsConstrucao.push(c.id)
            })

        if ($scope.relatorio.Fontes)
            $scope.relatorio.Fontes.forEach(f => {
                IdsFonte.push(f.id)
            })

        if($scope.relatorio.Fornecedores)
            $scope.relatorio.Fornecedores.forEach(f => {
                IdsFornecedores.push(f.label)
            })

        var tipoConta = ''
        if ($scope.relatorio.TipoConta)
            $scope.relatorio.TipoConta.forEach(t => {
                tipoConta += t.id.toString()
            })

        if (IdsConstrucao.length == 0 || IdsFonte.length == 0 || tipoConta == '')
            $scope.msgBoxAtencao('Extrato Contábil', 'Pelo menos uma obra, uma fonte e um tipo deve ser selecionada para gerar o extrato contábil.', () => { $scope.extrato = null; })
        else {
            var params = { 
                IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined,
                IdsConstrucao: JSON.stringify(IdsConstrucao), 
                IdsFonte: JSON.stringify(IdsFonte), 
                TipoConta: tipoConta, 
                Fornecedor: JSON.stringify(IdsFornecedores), 
                DataInicio: $filter("date")($scope.relatorio.DataInicio, 'yyyy-MM-dd'),
                DataFim: $filter("date")($scope.relatorio.DataFim, 'yyyy-MM-dd')
            }
            Relatorio.getRelatorioExtratoObra(params,
                (data) => {
                    CacheApp.setListaPedido($scope.relatorio);
                    $scope.extrato = data.Instance;
                }
            );
        }
    }

    $scope.getListaFontes = () => {
        var params = {IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined}
        Fonte.getListaFonte(params,
            (data) => {
                $scope.fontes = data.Instance;
                $scope.fontes.unshift({
                    IdFonte: '0',
                    Nome: 'Sem Fonte'
                });
                $scope.fontes.forEach(f => {
                    f.Id = f.IdFonte
                })
                $scope.getConstrucoesContabil();
            });
    }

    $scope.getListaTipo = () => {
        $scope.listaTipo = [
            {Id: 1, Nome: 'Pagas', Natureza: 0, DtPagNull: false},
            {Id: 2, Nome: 'A Pagar', Natureza: 0, DtPagNull: true},
            {Id: 3, Nome: 'Recebidas', Natureza: 1, DtPagNull: false},
            {Id: 4, Nome: 'A Receber', Natureza: 1, DtPagNull: true},
        ];
    }

    $scope.getConstrucoesContabil = () => {
        var params = {
            permissao: ($scope.sessao.TipoPlano == 1 || $scope.sessao.ContaAdmin) ? undefined : 'GET_FINANCEIRO', 
            refresh: false,
        }
        $scope.getListaObraCache(params, 
            (obra)=> {
                $scope.construcoes = obra
                var paramsFim = {
                    IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined,
                    Texto: '',
                    Situacao: 'Finalizada',
                    Paginacao: {
                        Index: 0,
                        Pages: 2000
                    }
                }
                Construcao.getListaObrasPaginacao(paramsFim,
                    (obrasFinalizadas) => {
                        obrasFinalizadas.Instance.forEach(o => {
                            if (!$scope.construcoes.some(c => c.Id == o.Id))
                                $scope.construcoes.push(o)
                        })
                        $scope.getFornecedores()
                    }
                )
            }
        )
    }

    $scope.detalharNota = (nota) => {
        var construcao = {};
        $scope.construcoes.forEach(c => {
            if(c.Id == nota.IdConstrucao)
                construcao = c;
        });

        var params = { 
            Tipo: 1, 
            IdConstrucao: construcao.Id,
            IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined
        }
        Construcao.getListaObras(params,
            (data) => {
                CacheApp.setConstrucao(data.Instance[0]);
                $scope.AtualizaConstrucao();                
                Compra.getNotasFiscais(construcao.Id, nota.IdNotaFiscal,
                    (data) => {
                        var notafiscal = data.Instance[0];
                        CacheApp.setNotaFiscal(notafiscal);
                        $location.path('/notafiscal/manter/' + (notafiscal.Natureza == 0 ? 'debito' : 'credito'));
                });
            }
        );
    };

    $scope.pdfExtratoObra = () => {
        var cabecalho = {
            Avatar: $scope.sessao.Avatar,
            Obra: '',
            Conta: $scope.sessao.Nome,
            DataInicio: $filter("date")($scope.relatorio.DataInicio, 'dd/MM/yyyy'),
            DataFim: $filter("date")($scope.relatorio.DataFim, 'dd/MM/yyyy')
        };

        var IdsConstrucao = [];
        var IdsFonte = [];
        var IdsFornecedores = [];

        if ($scope.relatorio.Construcoes)
            $scope.relatorio.Construcoes.forEach(c => {
                IdsConstrucao.push(c.id)
            })

        if ($scope.relatorio.Fontes)
            $scope.relatorio.Fontes.forEach(f => {
                IdsFonte.push(f.id)
            })

        if($scope.relatorio.Fornecedores)
            $scope.relatorio.Fornecedores.forEach(f => {
                IdsFornecedores.push(f.label)
            })

        var tipoConta = ''
        if ($scope.relatorio.TipoConta)
            $scope.relatorio.TipoConta.forEach(t => {
                tipoConta += t.id.toString()
            })

        if (IdsConstrucao.length == 0 || IdsFonte.length == 0 || tipoConta == '')
            $scope.msgBoxAtencao('Extrato Contábil', 'Pelo menos uma fonte e uma obra deve ser selecionada para gerar o extrato contábil.', () => { $scope.extrato = null; }) ;
        else {
            var params = { 
                IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined,
                IdsConstrucao: JSON.stringify(IdsConstrucao), 
                IdsFonte: JSON.stringify(IdsFonte), 
                TipoConta: tipoConta, 
                Fornecedor: JSON.stringify(IdsFornecedores), 
                DataInicio: $filter("date")($scope.relatorio.DataInicio, 'yyyy-MM-dd'),
                DataFim: $filter("date")($scope.relatorio.DataFim, 'yyyy-MM-dd'),
                Cabecalho: JSON.stringify(cabecalho)
            }
            Relatorio.pdfExtratoObra(params,
                (data) => {
                    window.location.assign(data.Instance);
                })
        }
    }

    $scope.xlsExtratoObra = () => {
        var cabecalho = {
            Avatar: $scope.sessao.Avatar,
            Obra: '',
            Conta: $scope.sessao.Nome,
            DataInicio: $filter("date")($scope.relatorio.DataInicio, 'dd/MM/yyyy'),
            DataFim: $filter("date")($scope.relatorio.DataFim, 'dd/MM/yyyy')
        };

        var IdsConstrucao = [];
        var IdsFonte = [];
        var IdsFornecedores = [];

        if ($scope.relatorio.Construcoes)
            $scope.relatorio.Construcoes.forEach(c => {
                IdsConstrucao.push(c.id)
            })

        if ($scope.relatorio.Fontes)
            $scope.relatorio.Fontes.forEach(f => {
                IdsFonte.push(f.id)
            })

        if($scope.relatorio.Fornecedores)
            $scope.relatorio.Fornecedores.forEach(f => {
                IdsFornecedores.push(f.label)
            })

        var tipoConta = ''
        if ($scope.relatorio.TipoConta)
            $scope.relatorio.TipoConta.forEach(t => {
                tipoConta += t.id.toString()
            })

        if (IdsConstrucao.length == 0 || IdsFonte.length == 0 || tipoConta == '')
            $scope.msgBoxAtencao('Extrato Contábil', 'Pelo menos uma fonte e uma obra deve ser selecionada para gerar o extrato contábil.', () => { $scope.extrato = null; })
        else
            var params = { 
                IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined,
                IdsConstrucao: JSON.stringify(IdsConstrucao), 
                IdsFonte: JSON.stringify(IdsFonte), 
                TipoConta: tipoConta, 
                Fornecedor: JSON.stringify(IdsFornecedores), 
                DataInicio: $filter("date")($scope.relatorio.DataInicio, 'yyyy-MM-dd'),
                DataFim: $filter("date")($scope.relatorio.DataFim, 'yyyy-MM-dd'),
                Cabecalho: JSON.stringify(cabecalho)
            }
            Relatorio.xlsExtratoObra(params,
                (data) => {
                    window.location.assign(data.Instance);
                }
            )
    }
    
    $scope.loadPage = () => {
        CacheApp.delConstrucao();
        CacheApp.delNotaFiscal();
        $scope.AtualizaConstrucao();                

        $scope.relatorio = CacheApp.getListaPedido(); //{};
        if (!$scope.relatorio) {
            $scope.relatorio = {};
            $scope.relatorio.DataInicio = CacheApp.getData($filter("date")(Date.now(), 'yyyy-MM-ddT00:00:00Z'));
            $scope.relatorio.DataFim = CacheApp.getData($filter("date")(Date.now(), 'yyyy-MM-ddT00:00:00Z'));
        }
        else {
            $scope.relatorio.DataInicio = CacheApp.getData($filter("date")($scope.relatorio.DataInicio, 'yyyy-MM-ddT00:00:00Z'));
            $scope.relatorio.DataFim = CacheApp.getData($filter("date")($scope.relatorio.DataFim, 'yyyy-MM-ddT00:00:00Z'));
            $scope.getRelatorioExtratoObra();
        }
    }

    $scope.AcessoAndroid($routeParams, (sim) => {
        $scope.getListaFontes();
        $scope.getListaTipo();
    });

  }]);
